/***************************************************************************
 *   Copyright (C) 2007 by David Bitseff                                   *
 *   dbitsef@zipcon.net                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <QSettings>
#include <QFile>
#include <QFileDialog>
#include <QMessageBox>
#include <QTextStream>

#include "scripteditwidget.h"
#include "logger.h"

ScriptEditWidget::ScriptEditWidget(MainWindow* m, QWidget *parent)
	: QWidget(parent), lua_thread(m)
{
	setupUi ( this );
	mw = m;

	QSettings settings;
	QString s = settings.value("script_editor_text", "").toString();
	m_scriptEdit->setPlainText(s);

	connect(m_runButton, SIGNAL(pressed()), this, SLOT(runScriptAction()));
	connect(m_openButton, SIGNAL(pressed()), this, SLOT(loadScript()));
	connect(m_saveButton, SIGNAL(pressed()), this, SLOT(saveScript()));
	connect(&lua_thread,  SIGNAL(scriptFinished()),
			this, SLOT(scriptFinishedAction()));
}


/*!
    \fn ScriptEditWidget::runScriptAction()
 */
void ScriptEditWidget::runScriptAction()
{
	QSettings settings;
	lua_thread.lua_text = m_scriptEdit->toPlainText();
	settings.setValue("script_editor_text", lua_thread.lua_text);
	if (lua_thread.isRunning())
		return;
	logInfo("ScriptEditWidget::runScriptAction : running script");
	lua_thread.start();
}


/*!
    \fn ScriptEditWidget::stopScriptAction()
 */
void ScriptEditWidget::stopScriptAction()
{
    /// @todo implement me
}


/*!
    \fn ScriptEditWidget::loadScript(QString filename)
 */
bool ScriptEditWidget::loadScript(QString filename)
{
    /// @todo implement me
	if (filename.isEmpty())
	{
		filename = QString(".lua");
		filename = QFileDialog::getOpenFileName(this, "Open a script",
				script_filename, "lua source (*.lua);;All files (*)");
		if (filename.isEmpty())
			return false;
	}

	QFile file(filename);
	if (!file.open(QIODevice::ReadOnly))
	{
		QMessageBox::warning(this, tr("Application error"),
									tr("Cannot read file %1\n").arg(filename));
		return false;
	}
	QTextStream os(&file);
	QString p = os.readAll();
	file.close();
	m_scriptEdit->setPlainText(p);
	m_filenameEdit->setText(filename);
	script_filename = filename;
	return true;
}


/*!
    \fn ScriptEditWidget::saveScript(QString filename=QString())
 */
bool ScriptEditWidget::saveScript(QString filename)
{
	if (filename.isEmpty())
	{
		filename = QString(".lua");
		filename = QFileDialog::getSaveFileName(this, "Save a script",
				script_filename, "lua source (*.lua);;All files (*)");
		if (filename.isEmpty())
			return false;
	}

	QFile file(filename);
	if (!file.open(QIODevice::WriteOnly | QIODevice::Truncate))
	{
		QMessageBox::warning(this, tr("Application error"),
									tr("Cannot write file %1\n").arg(filename));
		return false;
	}
	QTextStream os(&file);
	os << m_scriptEdit->toPlainText();
	file.close();
	script_filename = filename;
	return true;
}

bool ScriptEditWidget::save()
{
	return saveScript(script_filename);
}


void ScriptEditWidget::scriptFinishedAction()
{
	logInfo("ScriptEditWidget::scriptFinishedAction : finished script");
	mw->scriptFinishedSlot();
}

